from typing import Any

from fastel.config import SdkConfig
from fastel.payment.ecpay.models.map import CvsMapRequestModel
from fastel.utils import requests


def cvs_map_request(data: CvsMapRequestModel) -> Any:
    url = f"{SdkConfig.payment_host}/ecpay/logistics/map/request?client_id={SdkConfig.client_id}&client_secret={SdkConfig.client_secret}"
    result = requests.post(url, json=data.dict(exclude_none=True, by_alias=True))
    return result.json()



from typing import Literal, Optional

from pydantic import BaseModel, Field

from .logistics import CvsMapSubTypeOptions


class CvsMapRequestModel(BaseModel):
    logistics_type: Literal["CVS"] = Field(default="CVS", alias="LogisticsType")
    logistics_subtype: CvsMapSubTypeOptions = Field(
        default="FAMIC2C", alias="LogisticsSubType"
    )
    is_collection: Literal["Y", "N"] = Field(
        default="N", alias="IsCollection", description="是否收款"
    )
    device: Literal["0", "1"] = Field(
        default="0", alias="Device", description="PC:0; MOBILE:1"
    )
    redirect_url: Optional[str] = Field(default=None, alias="redirect_url")
